/*
 * Copyright (C) 2018 Wproject - Aitzol Berasategi
 *
 * This file is part of MacBank
 *
 * MacBank is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * MacBank is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.1
import QtQuick.Window 2.2
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import "components"

Page {
    id: helpPage
    visible: false

    header: PageHeader {
        id: helpHeader
        flickable: helpContainer
        title: i18n.tr(headerTitle)
        StyleHints {
            foregroundColor: "#FFFFFF"
            backgroundColor: "#1976D2"
            dividerColor: UbuntuColors.slate
        }

        leadingActionBar.actions: [
            Action {
                visible: true
                iconName: "back"
                text: "Back"
                onTriggered: {
                    pageStack.clear(helpPage)
                    pageStack.push(mainPage)
                    headerTitle = "MacBank"
                }
            }
        ]
        visible: true
    }

    Flickable {
        id: helpContainer

        anchors.fill: parent
        anchors.top: helpHeader.bottom
        contentHeight: helpList.height

        ListModel {
            id: helpModel
            dynamicRoles: true
            Component.onCompleted: initialise()
                function initialise(){
                    helpModel.append({ "title": i18n.tr("What is a MAC address?"), "content": i18n.tr("A MAC (Media Access Control) address is a unique identifier assigned to a NIC or Network Interface Controller. This MAC address is burned into a given device from the factory. A MAC address contains six pairs of hexadecimal digits, that is, it can only include the numbers 0-9 and letters A-F, usually separated by colons or dashes and will look something like this: BC:92:6B:69:2E:14.") })
                    helpModel.append({ "title": i18n.tr("What is a MAC address OUI?"), "content": i18n.tr("An OUI or Organizationally Unique Identifier is the first 24 bits out of an 48 bit MAC address which uniquely identifies a vendor, manufacturer, or the organization.") })
                    helpModel.append({ "title": i18n.tr("What is a MAC address IAB?"), "content": i18n.tr("An IAB or Individual Address Block is a 24-bit OUI managed by the IEEE Registration Authority, followed by 12 IEEE-provided bits (identifying the organization), and 12 bits for the owner to assign to individual devices.") })
                    helpModel.append({ "title": i18n.tr("How to use"), "content": i18n.tr("To find out the manufacturer of a MAC address, it is sufficient to use the first three octets, that is, the OUI, however you can use the full 48 bit address. Therefore enter any MAC address, OUI or IAB and find its vendor or manufacturer. Note that if you want to search for an IAB, you must insert the corresponding six octets, such as a full MAC address.") })
                }
        }

        Component {
            id: helpDelegate

            Column {
                spacing: 20
                width: parent.width

                Text {
                    id:foo
                    anchors {left: parent.left; right:parent.right; margins: units.gu(2) }
                    text: title
                    font.pointSize: units.dp(10)
                    font.weight: Font.Medium
                    color:UbuntuColors.jet
                }
                Text {
                    anchors {left: parent.left; right:parent.right; margins: units.gu(2) }
                    text: i18n.tr(content)
                    font.pointSize: units.dp(10)
                    width: parent.width
                    horizontalAlignment: Text.AlignJustify
                    wrapMode: Text.WordWrap
              }

            }
        }

        ListView {
            id:helpList
            anchors.fill: parent
            anchors.topMargin: units.gu(2)
            spacing: units.gu(4)
            model: helpModel
            delegate: helpDelegate
        }

        ScrollBar.vertical: ScrollBar {
            width: 10
            parent: helpContainer.parent
            anchors.top: helpContainer.top
            anchors.right: helpContainer.right
            anchors.bottom: helpContainer.bottom
            policy: ScrollBar.AsNeeded
        }

    }

}
