/*
 * Copyright (C) 2018 Wproject - Aitzol Berasategi
 *
 * This file is part of MacBank
 *
 * MacBank is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * MacBank is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.1
import QtQuick.Window 2.2
import Qt.labs.settings 1.0
import QtGraphicalEffects 1.0
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem
import io.thp.pyotherside 1.4
import "components"
import Macbank 1.0 // Macbank plugin


MainView {
    id: root
    objectName: 'mainView'
    applicationName: 'macbank.aitzol76'
    automaticOrientation: true

    width: units.gu(45)
    height: units.gu(75)

    backgroundColor:UbuntuColors.porcelain

    property var settings: Settings {
        property bool firstRun: true
        property string mode: 'OUI'
        property int show: 0
        property alias history: root.history
        property bool clear: true
    }

    property bool isVisible
    property bool deviceType: Macbank.isTouch //from C++ Macbank plugin
    property bool notEmpty: settings.history.length > 0 ? true : false
    property var elements: ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F"]
    property var orientation : width>height ? 2:1
    //property var sFactor: settings.mode == 'MAC' ? 1.2:1.8
    //property var sFactor: settings.mode == 'MAC' ? 0.4:0.6
    property var sFactor: density <= 10 ? settings.mode == 'MAC' ? 0.4:0.6 : settings.mode == 'MAC' ? 1.2:1.8
    property var history: []
    property string headerTitle: 'MacBank'
    property var version: '1.1.5'

    property int chars
    property int pbValue
    property real density: Screen.pixelDensity

    function modeCheck(){
      if(settings.mode == "OUI"){
        isVisible = false
        chars = 6
      }else{
        isVisible = true
        chars = 12
      }
    }

    function macListIndex(){
        if((settings.history.length > 0)&&(settings.show === 0)){
            macList.listview.currentIndex = settings.history.length-1
        }else{
            macList.listview.currentIndex = 0
        }
    }

    //window orientation
    Timer {
        id: timer
    }
    function delay(delayTime, cb) {
        timer.interval = delayTime;
        timer.repeat = false;
        timer.triggered.connect(cb);
        timer.start();
    }
    onWidthChanged: {
        delay(100, function() {
            var orientation = width>height ? 2:1
            console.log(density)
            macListIndex()
            console.log('index: '+macList.listview.currentIndex)
            return orientation
        })

    }

    //-----
    PageStack {
        id: pageStack
        Component.onCompleted: {
            // Show the welcome wizard only when running the app for the first time
            if (settings.firstRun) {
                console.log("[LOG]: Detecting first time run. Starting welcome wizard.")

                push(Qt.resolvedUrl("intro/Intro.qml"))
            } else {
                push(mainPage)
            }
        }

        Page {
            id: mainPage
            anchors.fill: parent
            visible: false


            MyProgressBar{
              id:progressbar
              anchors.top:header.bottom
              z: 2
            }

            header: MainHeader{
                        id:header
            }


            Flickable {
                id: ctrlPanel
                width: orientation === 1 ? parent.width : parent.width/2
                height: orientation === 1 ? (parent.height-header.height)/2 : parent.height-header.height
                anchors.left : orientation === 1 ? parent.left : parent.left
                anchors.top: header.bottom

                Rectangle {
                    id: entry
                    width: settings.mode == "MAC" ? (6*pair1.implicitWidth) + (5*separator1.implicitWidth) : (3*pair1.implicitWidth) + (2*separator1.implicitWidth)
                    height: pair1.implicitHeight + 10
                    transform: Scale { origin.x: entry.width/2; origin.y: 0; xScale: sFactor; yScale: sFactor}
                    anchors.top: parent.top
                    anchors.topMargin: units.gu(6)
                    anchors.horizontalCenter:parent.horizontalCenter
                    color:"transparent"

                    FontMetrics {
                        id: fontMetrics
                        font.pointSize: units.dp(12)
                    }

                    Component {
                        id: ouiFrame
                        Rectangle {
                            color: "white"
                            //border.color: "#21be2b"
                            border.color: UbuntuColors.silk
                            radius: 10
                        }
                    }

                    Component {
                        id: macFrame
                        Rectangle {
                            color: "#eeeeee"
                            //border.color: "#21be2b"
                            border.color: "#A6A6A6"
                            radius: 10
                        }
                    }

                    Frame {
                        id: pair1
                        background:ouiFrame.createObject(parent)
                        padding: 0
                        Row {
                            MyTumbler{
                              id:char1
                            }

                            MyTumbler{
                              id:char2
                            }

                        }
                    }

                    Separator{
                        id: separator1
                        anchors.left: pair1.right
                    }

                    Frame {
                        id: pair2
                        anchors.left: separator1.right
                        background:ouiFrame.createObject(parent)
                        padding: 0
                        Row {

                            MyTumbler{
                              id:char3
                            }

                            MyTumbler{
                              id:char4
                            }

                        }
                    }

                    Separator{
                        id: separator2
                        anchors.left: pair2.right
                    }

                    Frame {
                        id: pair3
                        anchors.left: separator2.right
                        background:ouiFrame.createObject(parent)
                        padding: 0
                        Row {

                            MyTumbler{
                              id:char5
                            }

                            MyTumbler{
                              id:char6
                            }

                        }
                    }

                    Separator{
                        id: separator3
                        anchors.left: pair3.right
                        visible: isVisible
                    }

                    Frame {
                        id: pair4
                        anchors.left: separator3.right
                        background:macFrame.createObject(parent)
                        padding: 0
                        visible: isVisible
                        Row {

                            MyTumbler{
                              id:char7
                            }

                            MyTumbler{
                              id:char8
                            }

                        }
                    }

                    Separator{
                        id: separator4
                        anchors.left: pair4.right
                        visible: isVisible
                    }

                    Frame {
                        id: pair5
                        anchors.left: separator4.right
                        background:macFrame.createObject(parent)
                        padding: 0
                        visible: isVisible
                        Row {

                            MyTumbler{
                              id:char9
                            }

                            MyTumbler{
                              id:char10
                            }

                        }
                    }

                    Separator{
                        id: separator5
                        anchors.left: pair5.right
                        visible: isVisible
                    }

                    Frame {
                        id: pair6
                        anchors.left: separator5.right
                        background:macFrame.createObject(parent)
                        padding: 0
                        visible: isVisible
                        Row {

                            MyTumbler{
                              id:char11
                            }

                            MyTumbler{
                              id:char12
                            }

                        }
                    }

                  }

                  SearchButton {
                      id:searchButton
                      anchors.bottom: parent.bottom
                      anchors.bottomMargin: units.gu(6)
                      anchors.horizontalCenter:parent.horizontalCenter
                  }
            }

            //List
            MacList {
                id: macList
            }

            Component.onCompleted:{
              modeCheck()
              macListIndex()
              progressbar.visible=false
            }

            Component.onDestruction: {
                settings.history = settings.history
                if(settings.clear){
                  settings.history = []
                  macList.macModel.clear()
                  notEmpty = false
                }

            }

        }

        SettingsPage{
          id:settingsPage
        }

        AboutPage{
          id:aboutPage
        }

        HelpPage{
          id:helpPage
        }

        ContentSharer { id: share }

        Python {
            id: python

            Component.onCompleted: {
                addImportPath(Qt.resolvedUrl('./'));
                importModule('app', function () {
                    call('app.main.db_connect', [], function(res){
                        //make something with "res"
                    });

                    call('app.main.file_check', [], function(res){
                      //make something with "res"
                    });
                });

                setHandler('progressbarValue', function (val) {
                    pbValue = val
                    val > 0 ? progressbar.indeterminate = false : progressbar.indeterminate = true
                    val < 10 ? progressbar.visible = true : progressbar.visible = false
                });

            }

            onError: {
                console.log('python error: ' + traceback);
                console.log(traceback)
            }


        }

    }

}
