/*
 * Copyright (C) 2018 Wproject - Aitzol Berasategi
 *
 * This file is part of MacBank
 *
 * MacBank is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * MacBank is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.1
import QtQuick.Window 2.2
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import "components"

Page {
    id: settingsPage
    visible: false

    header: PageHeader {
        id: settingsHeader
        flickable: settingsPlugin
        title: i18n.tr(headerTitle)
        StyleHints {
            foregroundColor: "#FFFFFF"
            backgroundColor: "#1976D2"
            dividerColor: UbuntuColors.slate
        }

        leadingActionBar.actions: [
            Action {
                visible: true
                iconName: "back"
                text: "Back"
                onTriggered: {
                    pageStack.clear(settingsPage)
                    pageStack.push(mainPage)
                    headerTitle = "MacBank"
                }
            }
        ]
        visible: true
    }

    //Listmodels
    ListModel {
        id: modeModel
        Component.onCompleted: initialise()
          function initialise() {
              modeModel.append({ "mode": "OUI" })
              modeModel.append({ "mode": "MAC" })
              //deSelection.subText.text = modeModel.get(settings.mode).mode
              modeSelection.subText.text = settings.mode
          }
    }
    ListModel {
        id: historyShowModel
        dynamicRoles: true
        Component.onCompleted: initialise()
          function initialise() {
              historyShowModel.append({ "show": i18n.tr("oldest"), "index": 0 })
              historyShowModel.append({ "show": i18n.tr("newest"), "index": 1 })
              historyShow.subText.text = historyShowModel.get(settings.show).show
          }
    }

    Flickable {
        id: settingsPlugin

        anchors.fill: parent
        contentHeight: _settingsColumn.height

        Column {
            id: _settingsColumn

            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }

            ListItemHeader {
                 id: searchModeListHeader
                 title: i18n.tr("Search mode")
                 dark: true
            }

            ExpandableListItem {
                id: modeSelection
                listViewHeight: units.gu(13)
                titleText.text: i18n.tr("Search by:")
                //subText.text: i18n.tr("")
                subText.textSize: Label.Medium

                model: modeModel

                delegate: ListItem {
                    divider.visible: false
                    ListItemLayout {
                        title.text: model.mode

                        Icon {
                            SlotsLayout.position: SlotsLayout.Trailing
                            width: units.gu(2)
                            height: width
                            name: "tick"
                            visible: settings.mode === model.mode
                            asynchronous: true
                        }
                    }
                    onClicked: {
                        settings.mode = model.mode
                        modeSelection.subText.text = model.mode
                        modeCheck()
                        modeSelection.expansion.expanded = false
                    }
                }
            }

            ListItemHeader {
                 id: historyListHeader
                 title: i18n.tr("History")
                 dark: true
            }

            ExpandableListItem {
                id: historyShow
                listViewHeight: units.gu(13)
                titleText.text: i18n.tr("Show first:")
                //subText.text: i18n.tr("")
                subText.textSize: Label.Medium

                model: historyShowModel

                delegate: ListItem {
                    divider.visible: false
                    ListItemLayout {
                        title.text: model.show

                        Icon {
                            SlotsLayout.position: SlotsLayout.Trailing
                            width: units.gu(2)
                            height: width
                            name: "tick"
                            visible: settings.show === model.index
                            asynchronous: true
                        }
                    }
                    onClicked: {
                        if(historyShow.subText.text != model.show){

                            settings.show = model.index
                            if(settings.history.length > 0){
                                settings.history.reverse()
                                macList.macModel.clear()
                                for(var i=0; i<settings.history.length; i++){
                                  macList.macModel.append(settings.history[i])
                                }
                                if(model.index === 0){
                                  macList.listview.currentIndex = settings.history.length-1
                                }

                            }

                        }

                        historyShow.subText.text = model.show
                        historyShow.expansion.expanded = false

                    }
                }
            }

            ListItem {
                height: clearOnExitLayout.height + divider.height
                ListItemLayout {
                    id: clearOnExitLayout
                    title.text: i18n.tr("Clear on exit")
                    Switch {
                        id: clearHistory
                        checked: settings.clear
                        onClicked: settings.clear = checked
                        SlotsLayout.position: SlotsLayout.Last
                    }
                }
            }

            ListItem {
                ListItemLayout {
                    title.text: i18n.tr("Clear")
                }
                //onClicked: PopupUtils.open(confirmEraseHistory)
                onClicked: {

                  if(settings.history.length > 0){

                      PopupUtils.open(Qt.resolvedUrl("components/Dialog.qml"), root, {
                          title: i18n.tr("Clear history"),
                          text: i18n.tr("Are you sure you want to clear the history?"),
                          buttonColor: UbuntuColors.green,
                          clear: true
                      })

                  }else{

                      PopupUtils.open(Qt.resolvedUrl("components/Dialog.qml"), root, {
                          title: i18n.tr("Clear history"),
                          text: i18n.tr("Your search history is empty."),
                          buttonColor: UbuntuColors.green,
                          clear: false
                      })

                  }

                }
            }

        }
    }

}
