'''
 * Copyright (C) 2018 Wproject - Aitzol Berasategi
 *
 * This file is part of MacBank
 *
 * MacBank is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * MacBank is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 '''

from io import open
import os
#import urllib.request
import requests
import sqlite3
from time import sleep
import pyotherside

class MainClass(object):

    def __init__(self):
        self.debug = ''
        self.result = {}
        self.dbDir = '/home/phablet/.local/share/macbank.aitzol76/Databases/'

    def file_check(self):

        if not os.path.exists(self.dbDir + 'source.txt'):
            self.on_update_clicked()
        else:
            return True

    def db_connect(self):

        if not os.path.exists(self.dbDir):
            os.makedirs(self.dbDir)

        # database connection
        try:
            #self.dbConnection = sqlite3.connect("/home/phablet/.local/share/macbank.aitzol76/Databases/a800b0b231b400980e8fef526760d58d") //testing
            self.dbConnection = sqlite3.connect(self.dbDir + 'macDB')
            self.dbCursor = self.dbConnection.cursor()
            self.dbCursor.execute("CREATE TABLE IF NOT EXISTS data(mac VARCHAR(20), vendor VARCHAR(50), UNIQUE('mac'))")
            self.debug = "OK"

        except sqlite3.Error as e:
            self.debug = e.args[0]

        finally:
            return self.debug

    def save_data(self):
        # read source file using "r"(read) parameter
        source_file = open(self.dbDir + "source.txt", "r")
        line = source_file.readlines()
        source_file.close()

        data = []
        for i in range(len(line)):
            try:
                if(line[i][0] != "#") and (line[i][0] != "\n"):
                    mac = line[i].split('\t', -1)[0][:17]
                    if mac == "00:00:00":
                        vendor = "Xerox Corporation"
                    else:
                        vendor = (line[i].split('\t', -1)[-1])[:-1]
                    data.append((mac, vendor))
            except Exception as e:
                print(e)

        self.dbCursor.executemany("INSERT OR REPLACE INTO data VALUES(?,?)", data)
        self.dbConnection.commit()

    def on_update_clicked(self):
        url = "https://gitlab.com/aitzol76/mac-vendors/raw/master/manuf"
        # url = "https://github.com/wireshark/wireshark/raw/master/manuf"

        try:
            r=requests.get(url)
            with open(self.dbDir + 'source.txt', 'w') as f:
                f.write(r.text)
                f.close()
            remote_file_size = len(r.text)
            size = round(int(remote_file_size))
            fraction = round(size/10)
            print(size)
            print(fraction)
            self.save_data()

            def progress_bar():
                i = 0
                value = 0

                while i < size:
                    value = value + 1
                    sleep(0.3)
                    i = i + fraction
                    pyotherside.send('progressbarValue', value)

                    if value == 10:
                        print("...updated!")
                        self.debug = "Success"
                        return self.debug
                        break

            return progress_bar()

        except Exception as e:
            self.debug = str(e)
            return self.debug

    def on_search_clicked(self, entry, mode):
        self.mode = mode
        entryToList = [entry[start:start+2] for start in range(0, len(entry), 2)]
        mac = ":".join(entryToList)
        self.dbCursor.execute("SELECT * FROM data WHERE mac=?", (mac.upper(),))
        self.rows = self.dbCursor.fetchall()

        if self.rows:
            for row in self.rows:
                self.result['mac'] = row[0]
                self.result['vendor'] = row[1]
                return self.result
        else:
            if self.mode == "MAC":
                mac48 = mac[:8] #mac address first 3 octets
                self.dbCursor.execute("SELECT * FROM data WHERE mac=?", (mac48.upper(),))
                self.rows = self.dbCursor.fetchall()
                if self.rows:
                    for row in self.rows:
                        #self.result['mac'] = row[0]
                        #self.result['vendor'] = row[1]
                        #return self.result

                        #-------------------------------
                        if row[1] == "IEEE Registration Authority":
                            iab_base = mac48 + ":00:00:00"
                            self.dbCursor.execute("SELECT * FROM data WHERE mac<=? AND mac>=? ORDER BY mac DESC LIMIT 1", (mac.upper(), iab_base.upper()))
                            self.rows = self.dbCursor.fetchall()

                            if self.rows:
                                for row in self.rows:
                                    #self.result = row
                                    #self.result = (self.search.upper(), row[1])
                                    self.result['mac'] = mac.upper()
                                    self.result['vendor'] = row[1]
                                    return self.result
                            else:
                                self.result['mac'] = mac.upper()
                                self.result['vendor'] = "Sorry, No results found!"
                                return self.result

                        else:
                            #self.result = row
                            #self.result = (self.search.upper(), row[1])
                            self.result['mac'] = mac.upper()
                            self.result['vendor'] = row[1]
                            return self.result
                        #--------------------------------




                else:
                    self.result['mac'] = mac.upper()
                    self.result['vendor'] = "Sorry, No results found!"
                    return self.result
            else:
                self.result['mac'] = mac.upper()
                self.result['vendor'] = "Sorry, No results found!"
                return self.result


main = MainClass()
