/*
 * Copyright (C) 2018 Wproject - Aitzol Berasategi
 *
 * This file is part of MacBank
 *
 * MacBank is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * MacBank is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Window 2.2
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem

Flickable {
    id: macContainer
    width: orientation === 1 ? parent.width : parent.width/2
    height: orientation === 1 ? (parent.height-header.height)/2 : parent.height-header.height
    anchors.right : orientation === 1 ? parent.right : parent.right
    anchors.top : orientation === 1 ? ctrlPanel.bottom : header.bottom

    property var macModel: custom_model   //reference to ListModel
    property var listview: macList        //reference to ListView

    Rectangle {
        id: verticalDivider
        border.width: .2
        height: orientation === 2 ? parent.height : 2
        width: orientation === 2 ? 2 : parent.width
        anchors.left: parent.left
        border.color: "#cccccc"
    }

    Item {
        id: listBackground
        width: parent.width
        height: parent.height
        visible: !notEmpty
        Icon {
            id:img
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            //width: density <= 10 ? 36 : 128
            //height: density <= 10 ? 36 : 128
            width: units.dp(36)
            height: units.dp(36)
            name: "clear"
        }
        Text {
            id: label
            anchors.horizontalCenter: img.horizontalCenter
            anchors.top: img.bottom
            anchors.topMargin: 5
            text: i18n.tr("Search history is empty")
            font.pointSize: units.dp(10)
        }
    }

    Component {
        id: headerComponent
        Rectangle {
            id: listHeader
            width: macList.width
            height: units.dp(40)
            color: UbuntuColors.silk
            z: 2
            Row {
                width: parent.width
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: 20

                Column {
                  width: parent.width/3
                  Text {
                      text: "MAC/OUI"
                      font.bold: true
                      font.pointSize: units.dp(10)
                      horizontalAlignment : Text.AlignHCenter
                      width: parent.width
                  }
                }
                Column {
                  width: parent.width - (parent.width/3)
                  Text {
                      text: i18n.tr("Vendor")
                      font.bold: true
                      font.pointSize: units.dp(10)
                      horizontalAlignment : Text.AlignHCenter
                      width: parent.width
                  }
                }
            }
        }
    }

    Component {
        id: listDelegate
        Row {
            width: parent.width
            SearchListItem {
                name: custom_model.count > 0 ? settings.history[index].mac : undefined
                content: custom_model.count > 0 ? settings.history[index].vendor : undefined
            }
        }
    }

    ListModel {
        id: custom_model
        Component.onCompleted:{
          for(var i=0; i<settings.history.length; i++){
            custom_model.append(settings.history[i])
          }
        }
     }

    ScrollView{
        width:macContainer.width
        anchors.fill: parent
        height: macList.implicitHeight

        ListView {
            id:macList
            model: custom_model.count > 0 ? custom_model : null
            delegate: listDelegate
            highlight: Rectangle { color: "#90CAF9"; radius: 5 }
            highlightFollowsCurrentItem : true
            focus: true
            header: headerComponent
            headerPositioning: ListView.PullBackHeader
            keyNavigationWraps: true
            visible: notEmpty
            /*
            remove: Transition {
                ParallelAnimation {
                    NumberAnimation { property: "opacity"; to: 0; duration: 1000 }
                    NumberAnimation { properties: "x,y"; to: 100; duration: 1000 }
                }
            }
            */
        }

    }
}
