/*
 * Copyright (C) 2018 Wproject - Aitzol Berasategi
 *
 * This file is part of MacBank
 *
 * MacBank is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * MacBank is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import Ubuntu.Components 1.3


ListItem {
    property var name: ""
    property var content: ""
    property var icon: ""
    property var iconColor: UbuntuColors.slate
    property bool progressSymbol
    height: layout.height + (divider.visible ? divider.height : 0)
    divider.visible: true

    leadingActions: ListItemActions {
        actions: [
            Action {
                iconName: "delete"
                onTriggered: {
                    console.log(index)
                    if(settings.history.length > 1) {
                        settings.history.splice(index, 1)
                        macModel.remove(index)
                        console.log('length: '+ settings.history.length)

                    }else if(settings.history.length == 1){
                        notEmpty = false
                        settings.history = []
                        macModel.clear()
                    }

                }
            }
        ]
    }

    trailingActions: ListItemActions {
        actions: [
            /*
            Action {
                iconName: "info"
                onTriggered: {//do something}
            },
            */
            Action {
                iconName: "share"
                onTriggered: share.share ( macModel.get(index).mac +" "+macModel.get(index).vendor)
            }
        ]
    }
    swipeEnabled: !mouseArea.drag.active
    Rectangle {
        color: "transparent"
        width: units.gu(2)
        height: width
        MouseArea {
            id: mouseArea
            anchors.fill: parent
            drag.target: parent
        }
    }

    Rectangle {
        id: leadingBorder
        width: 1
        height: parent.height
        anchors.left: parent.left
        color: "red"
        visible: swiped
    }

    Rectangle {
        id: trailingBorder
        width: 1
        height: parent.height
        anchors.right: parent.right
        color: UbuntuColors.silk
    }

    ListItemLayout {
        id: layout
        title.text: macModel.count > 0 ? name : ""
        //subtitle.text:

        Label{
            text: macModel.count > 0 ? content : ""
            color: UbuntuColors.ash
            horizontalAlignment : Text.AlignLeft
            width: parent.width - (parent.width/2)
        }

        Icon {
            name: icon
            color: iconColor
            width: units.gu(4)
            height: units.gu(4)
            SlotsLayout.position: SlotsLayout.Leading
            visible: icon != "" ? true : false
        }

        ProgressionSlot {
            visible: progressSymbol ? true : false
            SlotsLayout.position: SlotsLayout.Trailing
        }
    }
}
